---
search:
  exclude: true
---
# 发布流程/更新日志

本项目采用稍作修改的语义化版本控制，版本号形式为 `0.Y.Z`。前导的 `0` 表示 SDK 仍在快速迭代中。各组件递增规则如下：

## 次要（`Y`）版本

对于未标记为 beta 的任何公共接口出现的**不兼容变更**，我们将增加次要版本号 `Y`。例如，从 `0.0.x` 到 `0.1.x` 可能包含不兼容变更。

如果你不希望引入不兼容变更，建议在项目中固定到 `0.0.x` 版本。

## 补丁（`Z`）版本

对于不引入不兼容的变更，我们将增加 `Z`：

- Bug 修复
- 新功能
- 对私有接口的更改
- 对 beta 功能的更新

## 不兼容变更日志

### 0.2.0

在此版本中，一些过去接受 `Agent` 作为参数的地方，现在改为接受 `AgentBase` 作为参数。例如，MCP 服务中的 `list_tools()` 调用。这只是类型层面的变更，你仍会接收到 `Agent` 对象。要更新，只需将类型错误中的 `Agent` 替换为 `AgentBase` 即可。

### 0.1.0

在此版本中，[`MCPServer.list_tools()`][agents.mcp.server.MCPServer] 新增了两个参数：`run_context` 和 `agent`。对于任何继承 `MCPServer` 的类，你需要添加这些参数。